pub enum DeviceCompat {
Compatible(DeviceMode),
Untested(DeviceMode),
Incompatible,
}Expand description
Compatibility of a device, with detected mode if applicable.
Variants
Compatible(DeviceMode)
Known to speak the Bose DFU protocol. Usable by default.
Untested(DeviceMode)
May speak the Bose DFU protocol but has not been tested. Usable with --force flag. Mode
currently always DeviceMode::Unknown, but that may change if we find a non-PID way to
identify different modes (e.g. parsing the HID descriptor).
Incompatible
Definitely does not speak the Bose DFU protocol. Treated as if it doesn’t exist.